@@ -34,7 +34,7 @@ def latest(repo, output_format='version', pre_ok=False, assets_filter=False,
     }
     if repo.endswith('.yml'):
         with open(repo) as fpi:
-            repo_data = yaml.full_load(fpi)
+            repo_data = yaml.safe_load(fpi)
             if 'repo' in repo_data:
                 if 'nginx-extras' in repo:
                     repo_data['module_of'] = 'nginx'
@@ -112,7 +112,8 @@ def parse_version(tag):
 def main():
     parser = argparse.ArgumentParser(description='Get latest release from GitHub.',
                                      prog='lastversion')
-    parser.add_argument('action', nargs='?', default='get')
+    parser.add_argument('action', nargs='?', default='get', help='Special action to run, '
+                                                                 'e.g. test')
     parser.add_argument('repo', metavar='REPO',
                         help='GitHub repository in format owner/name')
     # affects what is considered last release
